package net.canreal.canrealsystem;

import net.canreal.canrealsystem.commands.StatCommand;
import net.canreal.canrealsystem.commands.TopCommand;
import net.canreal.canrealsystem.events.CommandPreprocessEvent;
import net.canreal.canrealsystem.events.PlayerKillEvent;
import net.canreal.canrealsystem.systemhandlers.ConfigHandler;
import net.canreal.canrealsystem.systemhandlers.MySQLHandler;
import org.bukkit.plugin.java.JavaPlugin;

import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.logging.Logger;

public final class Canrealsystem extends JavaPlugin {

    public static Logger log;
    public static String pluginName = "CanrealSystem";
    private static ConfigHandler configHandler;
    public static MySQLHandler mysqlHandler;

    @Override
    public void onEnable() {
        registerCommands();
        registerEvents();

        log = getLogger();
        configHandler = new ConfigHandler(this);

        if (configHandler.getString("database.typeOfDatabase").equalsIgnoreCase("mysql")) {
            log.info("Benutze MySQL Datenbank zum speichern der Daten.");
            loadMySQL();
            try {
                initializeDatabase();
            } catch (SQLException e) {
                throw new RuntimeException(e);
            }
        }

        log.info("erfolgreich geladen");
    }


    @Override
    public void onDisable() {

    }


    private void registerCommands() {
        // this.getCommand("plugins").setExecutor(new PluginCommand());
        this.getCommand("stat").setExecutor(new StatCommand());
        this.getCommand("top").setExecutor(new TopCommand());
    }

    private void registerEvents() {
        getServer().getPluginManager().registerEvents(new CommandPreprocessEvent(), this);
        getServer().getPluginManager().registerEvents(new PlayerKillEvent(), this);
    }

    public ConfigHandler getConfigHandler() {
        return configHandler;
    }

    public void loadMySQL() {
        mysqlHandler = new MySQLHandler(this);
    }

    private void initializeDatabase() throws SQLException {
        mysqlHandler = new MySQLHandler(this);
        String tableNamePVPKills = configHandler.getString("database.mysql.tableNamePVPKills");
        PreparedStatement ps = mysqlHandler.getConnection().prepareStatement("CREATE TABLE IF NOT EXISTS `" + tableNamePVPKills + "` (id" +
                " int(10) AUTO_INCREMENT, player_uuid varchar(50) NOT NULL UNIQUE, player_name varchar(50) NOT NULL, kill_count int(20) NOT NULL, killed_count int(20) NOT NULL, " +
                "PRIMARY KEY(id));");

        ps.executeUpdate();
    }
}
