package net.canreal.canrealsystem.systemhandlers;

import net.canreal.canrealsystem.Canrealsystem;
import org.bukkit.ChatColor;
import org.bukkit.entity.Player;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

public class ConfigHandler {
    private final Canrealsystem canrealsystem;

    public ConfigHandler(Canrealsystem canrealsystem) {
        this.canrealsystem = canrealsystem;
        loadConfig();
    }

    public void loadConfig() {
        // Check, if config exists and create it, if it doesn't exist
        File pluginFolder = new File("plugins" + System.getProperty("file.separator") + Canrealsystem.pluginName);
        if (!pluginFolder.exists()) {
            pluginFolder.mkdir();
        }

        // Check, if config file exists and create it, if it doesn't exist
        File configFile = new File("plugins" + System.getProperty("file.separator") + Canrealsystem.pluginName + System.getProperty("file.separator") + "config.yml");
        if (!configFile.exists()) {
            Canrealsystem.log.info("Keine Config gefunden. Config wird erstellt...");
            canrealsystem.saveDefaultConfig();
        }

        try {
            Canrealsystem.log.info("Config wird geladen...");
            canrealsystem.getConfig().load(configFile);
            Canrealsystem.log.info("Config erfolgreich geladen!");
        } catch (Exception e) {
            Canrealsystem.log.severe("Config konnte nicht erstellt werden! Error: " + e.getMessage());
            e.printStackTrace();
        }
    }

    public String getStringWithColor(String key) {
        if (!canrealsystem.getConfig().contains(key)) {
            Canrealsystem.log.severe("Konnte " + key + " nicht in der Config finden. Versuche eine neue Config zu generieren, indem " +
                    "du die aktuelle löschst.");
            return "errorCouldNotLocateInConfigYml:" + key;
        } else {
            return canrealsystem.getConfig().getString(key).replaceAll("&", "§");
        }
    }

    public String getString(String key) {
        if (!canrealsystem.getConfig().contains(key)) {
            Canrealsystem.log.severe("Konnte " + key + " nicht in der Config finden. Versuche eine neue Config zu generieren, indem " +
                    "du die aktuelle löschst.");
            return "errorCouldNotLocateInConfigYml:" + key;
        } else {
            return canrealsystem.getConfig().getString(key);
        }
    }

    public List<String> getStringList(String key) {
        if (!canrealsystem.getConfig().contains(key)) {
            Canrealsystem.log.severe("Konnte " + key + " nicht in der Config finden. Versuche eine neue Config zu generieren, indem " +
                    "du die aktuelle löschst.");
            return null;
        } else {
            return canrealsystem.getConfig().getStringList(key);
        }
    }

    public boolean getBoolean(String key) {
        if (!canrealsystem.getConfig().contains(key)) {
            Canrealsystem.log.severe("Konnte " + key + " nicht in der Config finden. Versuche eine neue Config zu generieren, indem " +
                    "du die aktuelle löschst.");
            return false;
        } else {
            return canrealsystem.getConfig().getBoolean(key);
        }
    }

    public double getDouble(String key) {
        if (!canrealsystem.getConfig().contains(key)) {
            Canrealsystem.log.severe("Konnte " + key + " nicht in der Config finden. Versuche eine neue Config zu generieren, indem " +
                    "du die aktuelle löschst.");
            return 0.0;
        } else {
            return canrealsystem.getConfig().getDouble(key);
        }
    }

    public int getInteger(String key) {
        if (!canrealsystem.getConfig().contains(key)) {
            Canrealsystem.log.severe("Konnte " + key + " nicht in der Config finden. Versuche eine neue Config zu generieren, indem " +
                    "du die aktuelle löschst.");
            return 0;
        } else {
            return canrealsystem.getConfig().getInt(key);
        }
    }

    public void printMessageFromConfig(Player player, String messageKey) {
        if (canrealsystem.getConfig().contains(messageKey)) {
            List<String> message = new ArrayList<String>();
            String configMsg = canrealsystem.getConfig().getString(messageKey);

            if (configMsg.matches("")) return;

            message.add(configMsg);

            if (player != null) {
                // Format message
                player.sendMessage(getString("chatMessage.prefix").replaceAll("&", "§") + message.get(0).replaceAll("&", "§"));
            }
        } else {
            Canrealsystem.log.severe("Konnte " + messageKey + " nicht in der Config finden. Versuche eine neue Config zu generieren, indem " +
                    "du die aktuelle löschst.");
            player.sendMessage(ChatColor.RED + "" + ChatColor.BOLD + "Canreal >>" + ChatColor.GRAY + "Konnte " + messageKey + " nicht " +
                    "in der Config finden.");
        }
    }
}
